@@ -9,7 +9,7 @@ pub fn read_to_end(fname: String) -> Result<Vec<Byte>, String> {
     };
 
     let mut buf: Vec<Byte> = Vec::new();
-    let fsize = match fp.read_to_end(&mut buf) {
+    let _fsize = match fp.read_to_end(&mut buf) {
         Ok(ok) => ok,
         Err(err) => return Err(format!("{:?}", err))
     };
