@@ -3,7 +3,9 @@ pub use super::*;
 pub mod lex;
 pub mod tok;
 pub mod pos;
+pub mod gen;
 
 pub use lex::*;
 pub use tok::*;
 pub use pos::*;
+pub use gen::*;
