@@ -3,11 +3,13 @@ pub mod rtne;
 pub mod arch;
 pub mod exec;
 pub mod ir;
+pub mod bin;
 
 pub use mem::*;
 pub use rtne::*;
 pub use arch::*;
 pub use exec::*;
+pub use bin::*;
 
 #[cfg(test)]
 mod tests {
